ffmpeg_pixel_format

Function ffmpeg_pixel_format 

pub fn ffmpeg_pixel_format(pixfmt: PixFmt) -> Result<&'static str, Error>
The ffmpeg raw-video (-f rawvideo) pixel-format name corresponding to a PixFmt, if the bytes can be piped to ffmpeg without any conversion on our side (ffmpeg itself does any conversion the encoder needs).

Returns Err(Error::UnimplementedPixelFormat) for formats that would require us to convert first (e.g. 32-bit float or planar formats).