pub struct FfmpegWriter { /* private fields */ }Expand description
Saves video frames to a video file using ffmpeg.
This spawns an ffmpeg process and pipes the frames as raw video
(-f rawvideo) with no intermediate format conversion on our side; ffmpeg
performs whatever conversion the chosen encoder requires. The ffmpeg process
is spawned lazily on the first frame, once the frame width, height and pixel
format are known.
Implementations
Sourceimpl FfmpegWriter
impl FfmpegWriter
pub fn new( fname: &str, ffmpeg_codec_args: FfmpegCodecArgs, rate: Option<(usize, usize)>, ) -> Result<Self, Error>
Sourcepub fn write_dynamic_frame(
&mut self,
frame: &DynamicFrame<'_>,
) -> Result<Duration, Error>
pub fn write_dynamic_frame( &mut self, frame: &DynamicFrame<'_>, ) -> Result<Duration, Error>
Write a frame. Return the presentation timestamp (PTS).
pub fn close(self) -> Result<(), Error>